/*
 * Filename: regfile_2.v
 * Description: Testbench for the register file.
 * Test:
 * Writes into register 1 and 2, reads the results back.
 * Author: Mark L. Chang
 */

`timescale 1 ps / 100 fs

// If the verilog file containing your register file is
// not named "regfile.v" then you will have to change
// to next line as appropriate.
`include "regfile.v"

module regfile_stimulus2;
   parameter clockDelay = 10000;

   reg [31:0] in_data;      // data to be written to regfile
   reg [4:0]  read_reg1;    // register to read1
   reg [4:0]  read_reg2;    // register to read2
   reg [4:0]  write_reg;    // register to write
   reg        write_enable; // write enable signal
   reg        clk;          // clock signal
   
   wire [31:0] out_data1;    // read register result 1
   wire [31:0] out_data2;    // read register result 2
   
   integer    i;

   // clock setup
   initial clk = 0;
   always #(clockDelay/2) clk = ~clk;
   
   // If your register file module is not named "regfile" then you will
   // have to change the following line in order to create an instance of
   // your register file.  Also you must make sure that the port declarations
   // match up with the module instance in this stimulus file.
   regfile thereg(out_data1,
      out_data2,
      in_data,
      read_reg1,
      read_reg2,
      write_reg,
      write_enable,
      clk);

   // stimulus   
   initial
     begin
  // set up to write into reg 1
  $dumpvars;
  write_enable = 0;
  read_reg1    = 0;
  read_reg2    = 0;
  write_reg    = 1;
  in_data      = 32'hFFFF;
  #(clockDelay);
  read_reg1    = 1;
  read_reg2    = 2;
  write_enable = 1;          // write reg 1
  #(clockDelay);
  // set up to write reg 2
  write_reg    = 2;
  in_data      = 32'hEEEE;   // writes at the leading edge of the next clock
  #(clockDelay);
  write_enable = 0;
  read_reg1    = 1;
  read_reg2    = 2;
  #(clockDelay);
  $finish;
     end // initial begin
   

   // response
   initial
     $monitor($time, ":  out_data1 = %h, out_data2 = %h, \nin_data = %h, write_enable = %b, \nread_reg1 = %h, read_reg2 = %h, write_reg = %h\n",
              out_data1, out_data2, in_data, write_enable,
	      read_reg1, read_reg2, write_reg);
   

endmodule // regfile_stimulus2


