/*
 * Filename: regfile_3.v
 * Description: Testbench for the register file.
 * Test:
 * Writes value into register 1.
 * Tries to write into register 2 with a very short write-enable.
 * Tests for glitch handling on the write-enable signal.
 * Author: Mark L. Chang
 */

`timescale 1 ps / 100 fs

// If the verilog file containing your register file is
// not named "regfile.v" then you will have to change
// to next line as appropriate.
`include "regfile.v"

module regfile_stimulus3;
   parameter clockDelay = 1000;

   reg [31:0] in_data;      // data to be written to regfile
   reg [4:0]  read_reg1;    // register to read1
   reg [4:0]  read_reg2;    // register to read2
   reg [4:0]  write_reg;    // register to write
   reg 	      write_enable; // write enable signal
   reg 	      clk;          // clock signal
   
   wire [31:0] out_data1;   // read register result 1
   wire [31:0] out_data2;   // read register result 2
   
   integer    i;

   // clock setup
   initial clk = 0;
   always #(clockDelay/2) clk = ~clk;
   
   // If your register file module is not named "regfile" then you will
   // have to change the following line in order to create an instance of
   // your register file.  Also you must make sure that the port declarations
   // match up with the module instance in this stimulus file.
   regfile thereg(out_data1,
		  out_data2,
		  in_data,
		  read_reg1,
		  read_reg2,
		  write_reg,
		  write_enable,
		  clk);

   // stimulus   
   initial
     begin
	// set up to write into reg 1
	$dumpvars;
	write_enable = 0;
	read_reg1    = 1;
	read_reg2    = 2;
	write_reg    = 1;
	in_data      = 32'hFFFFFFFF;
	#(clockDelay);
	write_enable = 1;   // write into register 1
	#(clockDelay); 

	/* the following tests a write-enable that just misses
	 * the rising edge of the clock. it stays high for the duration
	 * of the high clock, then falls to low. should not latch
	 * a new value into register 2 */
	write_enable     = 0;
	write_reg        = 2;
	in_data          = 32'hAAAAAAAA;
	#(clockDelay/2);         // wait until rising clock edge
	#10 write_enable = 1;    // wait 10 ticks, then raise write_enable
	// wait fall edge then lower write_enable
	#(clockDelay/2) write_enable = 0;

	// finish out to make it visible
	#(clockDelay);
	$finish;
     end // initial begin
   

   // response
   initial
     $monitor($time, ": clk = %b, out_data1 = %h, out_data2 = %h, \nin_data = %h, write_enable = %b, \nread_reg1 = %h, read_reg2 = %h, write_reg = %h\n",
	      clk, out_data1, out_data2, in_data, write_enable,
	      read_reg1, read_reg2, write_reg);
   

endmodule // regfile_stimulus3
