/*
 * Filename: regfile_4.v
 * Description: Testbench for the register file.
 * Test:
 * Writes into each register, then reads back.
 * Tests that reading works while writing, and that
 * basic read works at the end.
 * Author: Mark L. Chang
 */

`timescale 1 ps / 100 fs

// If the verilog file containing your register file is
// not named "regfile.v" then you will have to change
// to next line as appropriate.
`include "regfile.v"

module regfile_stimulus4;
   parameter clockDelay = 10000;

   reg [31:0] in_data;      // data to be written to regfile
   reg [4:0]  read_reg1;    // register to read1
   reg [4:0]  read_reg2;    // register to read2
   reg [4:0]  write_reg;    // register to write
   reg 	      write_enable; // write enable signal
   reg 	      clk;          // clock signal
   
   wire [31:0] out_data1;   // read register result 1
   wire [31:0] out_data2;   // read register result 2
   
   integer    i;

   // clock setup
   initial clk = 0;
   always #(clockDelay/2) clk = ~clk;
   
   // If your register file module is not named "regfile" then you will
   // have to change the following line in order to create an instance of
   // your register file.  Also you must make sure that the port declarations
   // match up with the module instance in this stimulus file.
   regfile thereg(out_data1,
		  out_data2,
		  in_data,
		  read_reg1,
		  read_reg2,
		  write_reg,
		  write_enable,
		  clk);

   // stimulus   
   initial
     begin
	$dumpvars;
	// Write a value into each  register.
	for (i = 1; i < 32; i = i + 1)
	  begin
	     write_enable = 0;
	     read_reg1    = i - 1;
	     read_reg2    = i;
	     write_reg    = i;
	     in_data      = i * 32'h100 + i;
	     #(clockDelay);
	     write_enable = 1;
	     #(clockDelay);
	  end // for (i = 1; i < 32; i = i + 1)

	// read back, no xxxxxx!
	for ( i = 0; i < 32; i = i + 1 )
	  begin
	     write_enable = 0;
	     read_reg1    = i;
	     read_reg2    = i;
	     write_reg    = i;
	     in_data      = 0;
	     #(clockDelay);
	  end
	$finish;
     end // initial begin

   

   // response
   initial
     $monitor($time, ":  out_data1 = %h, out_data2 = %h, \nin_data = %h, write_enable = %b, \nread_reg1 = %d, read_reg2 = %d, write_reg = %d\n",
	      out_data1, out_data2, in_data, write_enable,
	      read_reg1, read_reg2, write_reg);
   

endmodule // regfile_stimulus4


